package com.fs.hospital.service;

import java.util.List;
import com.fs.hospital.domain.HospitalMemberLevel;
import com.fs.hospital.vo.HospitalMemberLevelHVO;

/**
 * 会员等级Service接口
 *
 * @author fs
 * @date 2024-03-04
 */
public interface IHospitalMemberLevelService
{
    /**
     * 查询会员等级
     *
     * @param levelId 会员等级主键
     * @return 会员等级
     */
    public HospitalMemberLevel selectHospitalMemberLevelByLevelId(Long levelId);

    /**
     * 查询会员等级列表
     *
     * @param hospitalMemberLevel 会员等级
     * @return 会员等级集合
     */
    public List<HospitalMemberLevel> selectHospitalMemberLevelList(HospitalMemberLevel hospitalMemberLevel);

    /**
     * 新增会员等级
     *
     * @param hospitalMemberLevel 会员等级
     * @return 结果
     */
    public int insertHospitalMemberLevel(HospitalMemberLevel hospitalMemberLevel);

    /**
     * 修改会员等级
     *
     * @param hospitalMemberLevel 会员等级
     * @return 结果
     */
    public int updateHospitalMemberLevel(HospitalMemberLevel hospitalMemberLevel);

    /**
     * 批量删除会员等级
     *
     * @param levelIds 需要删除的会员等级主键集合
     * @return 结果
     */
    public int deleteHospitalMemberLevelByLevelIds(Long[] levelIds);

    /**
     * 删除会员等级信息
     *
     * @param levelId 会员等级主键
     * @return 结果
     */
    public int deleteHospitalMemberLevelByLevelId(Long levelId);

    List<HospitalMemberLevel> selectAllLevel(Long hospitalId);


    List<HospitalMemberLevelHVO> selectHospitalMemberLevelListPVO(HospitalMemberLevel hospitalMemberLevel);

}
